import re
from dosage.modules.helpers.BasicComicModule import BasicComicModule

class AsIf(BasicComicModule):
    latestUrl = 'http://asifcomic.com/404.html'
    imageUrl = 'http://www.asifcomic.com/%s.html'
    imageSearch = re.compile(r'<img src="((?:\.\./)*strips/\d+\..+?)"')
    prevSearch = re.compile(r'<a href="(?:\.\./)*(\d+\..+?)"><img[^>]*src="(?:\.\./)*previous\.jpg"', re.MULTILINE | re.IGNORECASE)
    help = 'Index format: nn(n) (padded up to a maximum of 2 characters)'
